[−][src]Enum unicode_types::emoticons::Emoticons
An enum to represent all characters in the Emoticons block.
Variants
GrinningFace\u{1f600}: '😀'
GrinningFaceWithSmilingEyes\u{1f601}: '😁'
FaceWithTearsOfJoy\u{1f602}: '😂'
SmilingFaceWithOpenMouth\u{1f603}: '😃'
SmilingFaceWithOpenMouthAndSmilingEyes\u{1f604}: '😄'
SmilingFaceWithOpenMouthAndColdSweat\u{1f605}: '😅'
SmilingFaceWithOpenMouthAndTightlyDashClosedEyes\u{1f606}: '😆'
SmilingFaceWithHalo\u{1f607}: '😇'
SmilingFaceWithHorns\u{1f608}: '😈'
WinkingFace\u{1f609}: '😉'
SmilingFaceWithSmilingEyes\u{1f60a}: '😊'
FaceSavouringDeliciousFood\u{1f60b}: '😋'
RelievedFace\u{1f60c}: '😌'
SmilingFaceWithHeartDashShapedEyes\u{1f60d}: '😍'
SmilingFaceWithSunglasses\u{1f60e}: '😎'
SmirkingFace\u{1f60f}: '😏'
NeutralFace\u{1f610}: '😐'
ExpressionlessFace\u{1f611}: '😑'
UnamusedFace\u{1f612}: '😒'
FaceWithColdSweat\u{1f613}: '😓'
PensiveFace\u{1f614}: '😔'
ConfusedFace\u{1f615}: '😕'
ConfoundedFace\u{1f616}: '😖'
KissingFace\u{1f617}: '😗'
FaceThrowingAKiss\u{1f618}: '😘'
KissingFaceWithSmilingEyes\u{1f619}: '😙'
KissingFaceWithClosedEyes\u{1f61a}: '😚'
FaceWithStuckDashOutTongue\u{1f61b}: '😛'
FaceWithStuckDashOutTongueAndWinkingEye\u{1f61c}: '😜'
FaceWithStuckDashOutTongueAndTightlyDashClosedEyes\u{1f61d}: '😝'
DisappointedFace\u{1f61e}: '😞'
WorriedFace\u{1f61f}: '😟'
AngryFace\u{1f620}: '😠'
PoutingFace\u{1f621}: '😡'
CryingFace\u{1f622}: '😢'
PerseveringFace\u{1f623}: '😣'
FaceWithLookOfTriumph\u{1f624}: '😤'
DisappointedButRelievedFace\u{1f625}: '😥'
FrowningFaceWithOpenMouth\u{1f626}: '😦'
AnguishedFace\u{1f627}: '😧'
FearfulFace\u{1f628}: '😨'
WearyFace\u{1f629}: '😩'
SleepyFace\u{1f62a}: '😪'
TiredFace\u{1f62b}: '😫'
GrimacingFace\u{1f62c}: '😬'
LoudlyCryingFace\u{1f62d}: '😭'
FaceWithOpenMouth\u{1f62e}: '😮'
HushedFace\u{1f62f}: '😯'
FaceWithOpenMouthAndColdSweat\u{1f630}: '😰'
FaceScreamingInFear\u{1f631}: '😱'
AstonishedFace\u{1f632}: '😲'
FlushedFace\u{1f633}: '😳'
SleepingFace\u{1f634}: '😴'
DizzyFace\u{1f635}: '😵'
FaceWithoutMouth\u{1f636}: '😶'
FaceWithMedicalMask\u{1f637}: '😷'
GrinningCatFaceWithSmilingEyes\u{1f638}: '😸'
CatFaceWithTearsOfJoy\u{1f639}: '😹'
SmilingCatFaceWithOpenMouth\u{1f63a}: '😺'
SmilingCatFaceWithHeartDashShapedEyes\u{1f63b}: '😻'
CatFaceWithWrySmile\u{1f63c}: '😼'
KissingCatFaceWithClosedEyes\u{1f63d}: '😽'
PoutingCatFace\u{1f63e}: '😾'
CryingCatFace\u{1f63f}: '😿'
WearyCatFace\u{1f640}: '🙀'
SlightlyFrowningFace\u{1f641}: '🙁'
SlightlySmilingFace\u{1f642}: '🙂'
UpsideDashDownFace\u{1f643}: '🙃'
FaceWithRollingEyes\u{1f644}: '🙄'
FaceWithNoGoodGesture\u{1f645}: '🙅'
FaceWithOkGesture\u{1f646}: '🙆'
PersonBowingDeeply\u{1f647}: '🙇'
SeeDashNoDashEvilMonkey\u{1f648}: '🙈'
HearDashNoDashEvilMonkey\u{1f649}: '🙉'
SpeakDashNoDashEvilMonkey\u{1f64a}: '🙊'
HappyPersonRaisingOneHand\u{1f64b}: '🙋'
PersonRaisingBothHandsInCelebration\u{1f64c}: '🙌'
PersonFrowning\u{1f64d}: '🙍'
PersonWithPoutingFace\u{1f64e}: '🙎'
Methods
impl Emoticons[src]
pub fn new() -> Self[src]
The character with the lowest index in this unicode block
pub fn name(&self) -> String[src]
The character's name, in sentence case